/* Indonesian translation for the jQuery Timepicker Addon */
/* Written by Nia */
(function($) {
	$.timepicker.regional['id'] = {
		timeOnlyTitle: 'Pilih Waktu',
		timeText: 'Waktu',
		hourText: 'Pukul',
		minuteText: 'Menit',
		secondText: 'Detik',
		millisecText: 'Milidetik',
		timezoneText: 'Zona Waktu',
		currentText: 'Sekarang',
		closeText: 'OK',
		timeFormat: 'hh:mm tt',
		amNames: ['AM', 'A'],
		pmNames: ['PM', 'P'],
		ampm: false,
		isRTL: false
	};
	$.timepicker.setDefaults($.timepicker.regional['id']);
})(jQuery);
